@@ -9,8 +9,8 @@ logger = logging.getLogger(__name__);
 class ModuleCaching(module.Module):
     '''Extended module that is caching the current hardware state locally'''
     
-    inputs = [] # list of current input states
-    motor_speeds = [] # list of current motor speeds
+    inputs = None # list of current input states
+    motor_speeds = None # list of current motor speeds
     
     def __init__(self):
         '''Constructor to initialize member variables'''
